# Copyright (c) Microsoft Corporation
# Licensed under the MIT License.

"""Module for rai_core_flask service."""

from .flask_helper import FlaskHelper

__all__ = ['FlaskHelper']
